@@ -46,6 +46,7 @@ class EventManager:
 
     def __init__(self):
 
+        debug.println(debug.LEVEL_FINEST, 'INFO: Initializing event manager')
         self._scriptListenerCounts = {}
         self.registry = pyatspi.Registry
         self._enqueueCount = 0
@@ -54,10 +55,13 @@ class EventManager:
         self._gidleId        = 0
         self._gidleLock      = threading.Lock()
         self.noFocusTimestamp = 0.0
+        debug.println(debug.LEVEL_FINEST, 'INFO: Event manager initialized')
 
     def activate(self):
         """Called when this presentation manager is activated."""
 
+        debug.println(debug.LEVEL_FINEST, 'INFO: Activating event manager')
+
         global _scriptManager
         _scriptManager = getattr(orca, '_scriptManager')
 
@@ -69,13 +73,16 @@ class EventManager:
         self._registerListener("window:deactivate")
         self._registerListener("object:children-changed")
         self._registerListener("mouse:button")
+        debug.println(debug.LEVEL_FINEST, 'INFO: Event manager activated')
 
     def deactivate(self):
         """Called when this event manager is deactivated."""
 
+        debug.println(debug.LEVEL_FINEST, 'INFO: Dectivating event manager')
         for eventType in self._scriptListenerCounts.keys():
             self.registry.deregisterEventListener(self._enqueue, eventType)
         self._scriptListenerCounts = {}
+        debug.println(debug.LEVEL_FINEST, 'INFO: Event manager deactivated')
 
     def _ignore(self, event):
         """Returns True if this event should be ignored."""
@@ -274,6 +281,10 @@ class EventManager:
         - eventType: the event type.
         """
 
+        debug.println(debug.LEVEL_FINEST,
+                      'INFO: Event manager registering listener for: %s' \
+                       % eventType)
+
         if eventType in self._scriptListenerCounts:
             self._scriptListenerCounts[eventType] += 1
         else:
@@ -287,6 +298,10 @@ class EventManager:
         - eventType: the event type.
         """
 
+        debug.println(debug.LEVEL_FINEST,
+                      'INFO: Event manager deregistering listener for: %s' \
+                       % eventType)
+
         if not eventType in self._scriptListenerCounts:
             return
 
@@ -303,6 +318,10 @@ class EventManager:
         - script: the script.
         """
 
+        debug.println(debug.LEVEL_FINEST,
+                      'INFO: Event manager registering listeners for: %s' \
+                       % script)
+
         for eventType in script.listeners.keys():
             self._registerListener(eventType)
 
@@ -314,6 +333,10 @@ class EventManager:
         - script: the script.
         """
 
+        debug.println(debug.LEVEL_FINEST,
+                      'INFO: Event manager deregistering listeners for: %s' \
+                       % script)
+
         for eventType in script.listeners.keys():
             self._deregisterListener(eventType)
 
@@ -332,6 +355,11 @@ class EventManager:
     def registerKeystrokeListener(self, function, mask=None, kind=None):
         """Register the keystroke listener on behalf of the caller."""
 
+        debug.println(
+            debug.LEVEL_FINEST,
+            'INFO: Event manager registering keystroke listener function: %s' \
+             % function)
+
         if mask == None:
             mask = range(256)
 
@@ -343,6 +371,11 @@ class EventManager:
     def deregisterKeystrokeListener(self, function, mask=None, kind=None):
         """Deregister the keystroke listener on behalf of the caller."""
 
+        debug.println(
+            debug.LEVEL_FINEST,
+            'INFO: Event manager deregistering keystroke listener function: %s'\
+             % function)
+
         if mask == None:
             mask = range(256)
 
@@ -393,6 +426,10 @@ class EventManager:
         script = None
         try:
             app = event.host_application or event.source.getApplication()
+            if app and app.getState().contains(pyatspi.STATE_DEFUNCT):
+                msg = 'WARNING: App is defunct. Cannot get script for event.'
+                debug.println(debug.LEVEL_WARNING, msg)
+                return None
         except:
             debug.printException(debug.LEVEL_WARNING)
         else:
@@ -518,6 +555,9 @@ class EventManager:
             debug.printDetails(debug.LEVEL_FINEST, "    ", event.source)
 
         script = self._getScriptForEvent(event)
+        if not script:
+            return
+
         debug.println(debug.LEVEL_FINEST, "Script for event: %s" % script.name)
         setNewActiveScript, reason = self._isActivatableEvent(event, script)
         if setNewActiveScript:
