@@ -33,17 +33,21 @@ import os
 import imp
 from dbus.mainloop.glib import DBusGMainLoop
 from json import load
+from xdg.BaseDirectory import xdg_data_home
 
 import debug
 from keybindings import KeyBinding
 import settings
 import pronunciation_dict
 
-_dbusLoop = DBusGMainLoop()
-_bus = dbus.SessionBus(mainloop=_dbusLoop)
-_proxy = _bus.get_object("org.a11y.Bus", "/org/a11y/bus")
-_desktopProps = \
-    dbus.Interface(_proxy, dbus_interface='org.freedesktop.DBus.Properties')
+try:
+    _dbusLoop = DBusGMainLoop()
+    _bus = dbus.SessionBus(mainloop=_dbusLoop)
+    _proxy = _bus.get_object("org.a11y.Bus", "/org/a11y/bus")
+    _desktopProps = \
+        dbus.Interface(_proxy, dbus_interface='org.freedesktop.DBus.Properties')
+except:
+    _desktopProps = None
 
 class SettingsManager(object):
     """Settings backend manager. This class manages orca user's settings
@@ -55,7 +59,7 @@ class SettingsManager(object):
             cls.__instance = object.__new__(cls, *args, **kwargs)
         return cls.__instance
 
-    def __init__(self, backend='json'):
+    def __init__(self, backend='json', prefsDir=None):
         """Initialize a SettingsManager Object.
         If backend isn't defined then uses default backend, in this
         case json-backend.
@@ -63,10 +67,13 @@ class SettingsManager(object):
         backend='json'
         """
 
+        debug.println(debug.LEVEL_FINEST, 'INFO: Initializing settings manager')
+
         self.backendModule = None
         self._backend = None
         self.profile = None
         self.backendName = backend
+        self._prefsDir = prefsDir or os.path.join(xdg_data_home, "orca")
 
         # Dictionaries for store the default values
         # The keys and values are defined at orca.settings
@@ -99,7 +106,7 @@ class SettingsManager(object):
         self._customizationCompleted = False
 
         # Load the backend and the default values
-        self._backend = self.backendModule.Backend()
+        self._backend = self.backendModule.Backend(self._prefsDir)
         self._setDefaultGeneral()
         self._setDefaultPronunciations()
         self._setDefaultKeybindings()
@@ -114,8 +121,7 @@ class SettingsManager(object):
         # yet, so we need to create the user config directories and store the
         # initial default settings
         #
-        if self.isFirstStart():
-            self._createDefaults()
+        self._createDefaults()
 
         # Set the active profile and load its stored settings
         if self.profile is None:
@@ -126,6 +132,8 @@ class SettingsManager(object):
         self.settingsPackages = ["app-settings"]
         self._knownAppSettings = {}
 
+        debug.println(debug.LEVEL_FINEST, 'INFO: Settings manager initialized')
+
     def _loadBackend(self):
         """Load specific backend for manage user settings"""
 
@@ -143,12 +151,12 @@ class SettingsManager(object):
         orca.settings"""
         def _createDir(dirName):
             if not os.path.isdir(dirName):
-                os.mkdir(dirName)
+                os.makedirs(dirName)
 
         # Set up the user's preferences directory
         # ($XDG_DATA_HOME/orca by default).
         #
-        orcaDir = settings.userPrefsDir
+        orcaDir = self._prefsDir
         _createDir(orcaDir)
 
         # Set up $XDG_DATA_HOME/orca/orca-scripts as a Python package
@@ -177,10 +185,10 @@ class SettingsManager(object):
         if not os.path.exists(userCustomFile):
             os.close(os.open(userCustomFile, os.O_CREAT, 0700))
 
-
-        self._backend.saveDefaultSettings(self.defaultGeneral,
-                                          self.defaultPronunciations,
-                                          self.defaultKeybindings)
+        if self.isFirstStart():
+            self._backend.saveDefaultSettings(self.defaultGeneral,
+                                              self.defaultPronunciations,
+                                              self.defaultKeybindings)
 
     def _setDefaultPronunciations(self):
         """Get the pronunciations by default from orca.settings"""
@@ -224,7 +232,7 @@ class SettingsManager(object):
         likelihood that the results won't be different if we keep trying."""
 
         success = False
-        pathList = [settings.userPrefsDir]
+        pathList = [self._prefsDir]
         try:
             msg = "Attempt to load orca-customizations "
             (fileHnd, moduleName, desc) = \
@@ -243,6 +251,9 @@ class SettingsManager(object):
         debug.println(debug.LEVEL_ALL, msg)
         return success
 
+    def getPrefsDir(self):
+        return self._prefsDir
+
     def setSetting(self, settingName, settingValue):
         self._setSettingsRuntime({settingName:settingValue})
 
@@ -304,9 +315,15 @@ class SettingsManager(object):
         return not alreadyEnabled
 
     def isAccessibilityEnabled(self):
+        if not _desktopProps:
+            return False
+
         return bool(_desktopProps.Get('org.a11y.Status', 'IsEnabled'))
 
     def setAccessibility(self, enable):
+        if not _desktopProps:
+            return False
+
         _desktopProps.Set('org.a11y.Status', 'IsEnabled', enable)
         return True
 
@@ -315,6 +332,9 @@ class SettingsManager(object):
         this does not necessarily mean that Orca (or any other screen reader)
         is running at the moment."""
 
+        if not _desktopProps:
+            return False
+
         return bool(_desktopProps.Get('org.a11y.Status', 'ScreenReaderEnabled'))
 
     def setStartingProfile(self, profile=None):
